/// <reference types="node" />
import TypedEmitter from 'typed-emitter';
import * as protocol from '.';
import { LunarClientPluginChannel } from '../constants';
declare type LunarClientPacketReaderEvents = {
    [key in keyof typeof protocol]: (packet: InstanceType<typeof protocol[key]>) => void;
};
declare const LunarClientPacketReader_base: new () => TypedEmitter<LunarClientPacketReaderEvents>;
/**
 * Instantiate a new PacketHandler class.
 * This class extends EventEmitter and for
 * each successfuly handled packet the event
 * emitter will emit an event. If a `CooldownPacket`
 * is received, an event with name `CooldownPacket`
 * is emitted.
 *
 * @example
 * ```javascript
 * const packetReader = new LunarClientPacketReader();
 *
 * // Call PacketReader#read with
 * // the buffer everytime you receive
 * // a packet
 *
 * packetReader.on('CooldownPacket', ({ data }) => {
 *   // Do something with data
 * });
 * ```
 */
export default class LunarClientPacketReader extends LunarClientPacketReader_base {
    /**
     * Read a packet, if everything is successful
     * an event will be emited with the content of
     * the packet
     * @param buffer The raw packet to read
     * @param channel The plugin channel the packet comes from. Defauts to `LunarClientPacketReader.NEW`
     */
    read(buffer: Buffer, channel?: LunarClientPluginChannel): void;
}
export {};
